@@ -62,7 +62,7 @@ class ESA:
         result = {}
 
         if self._sim == "cos":
-            result_vector= Similarity.cosine_similarity(document_vec, self._mat)
+            result_vector= Similarity.cosine_similarity(document_vec, self._mat.get_mat().transpose().todense())
             for i,concept in enumerate(self._mat.get_concepts()):
                 result[concept] = result_vector[i]
 
